<template>
	<div class="pc-prompts">
		<div class="title flex items-center justify-between">
			<div class="flex item-center">
				<span>提问示例</span>
				<span class="split"></span>
				<span class="change cursor-pointer" @click="advanceExampleClick">高级示例 ></span>
			</div>
			<div class="cursor-pointer">
				<span class="mr-1 changeBatch">换一批</span>
				<i class="iconfont icon-shuaxin"></i>
			</div>
		</div>

		<div class="main">
			<div
				class="main_item flex items-center cursor-pointer"
				v-for="(item, index) in state.exampleContent"
				:key="item.ID"
				:class="{ main_item_active: item.ID === state.exampleIndex }"
				@click="changeExample(item)"
			>
				<div class="left flex items-center justify-center" :class="['color' + index]">
					<img :src="item.Icon" alt="" />
				</div>
				<div class="right">
					<h4>{{ item.Title }}</h4>
					<p>{{ item.Content }}</p>
				</div>
			</div>
		</div>
		<el-drawer v-model="state.isShowAdvanceExample" direction="rtl" size="354">
			<div class="box-border w100 bg-[#e0e7fb] relative flex items-center justify-center" style="padding: 30px 20px 26px">
				<div
					class="box-border flex w-[203px] h-[32px] rounded-md items-center justify-between cursor-pointer relative border border-solid border-[#2c2d33]"
				>
					<!-- <div class="w-[108px] h100 rounded-[5px] bg-transparent absolute left-0 transition-all"></div> -->

					<div
						class="tabbar-item"
						:class="state.activeName === item.ID ? 'set-tabbar-active' : ''"
						@click="handleTabClick(item)"
						v-for="item in state.tabNameList"
						:key="item.ID"
					>
						{{ item.Name }}
					</div>
				</div>
			</div>
			<div class="box-border w-[354px] flex-1 min-h-0 bg-[#e0e7fb]" style="height: calc(100% - 88px)">
				<div class="flex flex-col w100 h100 pt-0 pr-[15px] pb-0 pl-[20px] overflow-auto">
					<div class="flex items-center w100 h-[30px] border border-solid border-[#b2b2b2] transition-[border-color 1s] rounded-2xl">
						<el-input v-model="state.searchInput" placeholder="搜索更多" class="set-input" :prefix-icon="Search"> </el-input>
					</div>
					<div class="mt20 w100 relative">
						<div
							class="overflow-hidden max-h-[36px] transition-[max-height 0.2s] w100 flex flex-wrap text-xs leading-[14px] m-[-5px]"
							:class="{ 'set-expand-active': state.isShowExpand }"
						>
							<div
								v-for="item in state.exampleTabList"
								:key="item.ID"
								:class="{ 'set-label-active': state.activeLabelName === item.ID }"
								@click="handleLabelClick(item)"
								class="cursor-pointer m-[5px] py-[5px] px-[10px] rounded-xl border border-solid border-[#b2b2b2] bg-[#e0e7f] text-[#4c4c4c] transition-[background-color .1s, color .1s, border-color .1s]"
							>
								{{ item.Title }}
							</div>
						</div>
						<div class="bg-[#e0e7fb] absolute right-0 top-0 text-[#131313] w-[30px] h-[26px] cursor-pointer flex items-center">
							<i class="iconfont icon-bolangneng" title="展开" @click="handleExpandClick(1)" v-show="!state.isShowExpand"></i>
							<i class="iconfont icon-zhongduancanshu" title="收缩" @click="handleExpandClick(2)" v-show="state.isShowExpand"></i>
						</div>
						<div class="mt20 w100">
							<div class="w100 pb-[20px]" v-for="item in state.exampleContentList" :key="item.ID">
								<div class="cursor-pointer flex box-border p-[12px] w100 rounded bg-[#f5f7fd] transition-[background-color .2s]">
									<i
										class="iconfont icon-chazhaobiaodanliebiao pl-[2px] w-[16px] h-[16px] font12 text-[#fff] transform-[scale(.85)] rounded-[50%]"
										:style="`background-color:${item.BgColor}`"
									></i>
									<div class="ml-6 flex-1 min-w-0">
										<div class="text-sm text-[#000] m-0 p-0 font-bold">{{ item.Title }}</div>
										<div class="mt-[6px] text-[13px] text-[#666] h-[20px] whitespace-nowrap text-ellipsis overflow-hidden">
											{{ item.Content }}
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</el-drawer>
	</div>
</template>

<script setup lang="ts">
import { Search } from '@element-plus/icons-vue';
import { onMounted, reactive } from 'vue';
let state = reactive({
	exampleContent: [
		{
			ID: 1,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '解读李四的反应',
			Content: '张三打了李四一巴掌,李四对张三说:"你是不是没吃饭",李四说这句话含义是?',
		},
		{
			ID: 2,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '解释努力与内卷的区别',
			Content: '怎么解释努力和内卷的区别?',
		},
		{
			ID: 3,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '其他问题',
			Content: '请搜索你想知道的问题',
		},
		{
			ID: 4,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '给宝宝取有文化内涵的名字',
			Content: '请以诗经中的典故给男宝宝取名，姓顾，名字要求3个字，给5个名字供我选择。',
		},
	],
	tabNameList: [
		{ ID: 1, Name: '提问示例' },
		{ ID: 2, Name: '指令模板' },
	],
	exampleIndex: 0,
	isShowAdvanceExample: false,
	activeName: 1,
	searchInput: '',
	exampleTabList: [
		{
			ID: 1,
			Title: '工作',
		},
		{
			ID: 2,
			Title: '职场',
		},
		{
			ID: 3,
			Title: '科学',
		},
		{
			ID: 4,
			Title: '求职',
		},
		{
			ID: 5,
			Title: '新能源,汽车,数据',
		},
		{
			ID: 6,
			Title: '写作',
		},
		{
			ID: 7,
			Title: '学习',
		},
		{
			ID: 8,
			Title: '创作',
		},
	],
	exampleContentList: [
		{
			ID: 1,
			Title: '如何提升自己的职场竞争力？',
			Content:
				'职场竞争力是衡量一个人是否成功的重要标准。职场竞争力的提升，需要长期的努力和坚持。下面是一些提升职场竞争力的方法：1. 保持专注：专注于自己的工作，不断学习新技能，提升技能水平。2. 保持学习：不断学习新知识，不断提升自己的专业知识。3. 保持热情：保持积极向上的心态，不断追求新事物。4. 保持适当的休息：适当的休息可以让身体更加健康，提高工作效率。5. 保持积极的态度：积极的态度可以激发员工的创造力，提升工作的积极性。',
		},
		{
			ID: 2,
			Title: '爱护动物视频剧本',
			Content: '请担任编剧，我需要拍摄一个关于爱护动物的视频，请给我生成拍摄内容和脚本',
		},
		{
			ID: 3,
			Title: '波粒二象性',
			Content: '解释一下波粒二象性理论',
		},
		{
			ID: 4,
			Title: '如何提升自己的职场竞争力？',
			Content:
				'职场竞争力是衡量一个人是否成功的重要标准。职场竞争力的提升，需要长期的努力和坚持。下面是一些提升职场竞争力的方法：1. 保持专注：专注于自己的工作，不断学习新技能，提升技能水平。2. 保持学习：不断学习新知识，不断提升自己的专业知识。3. 保持热情：保持积极向上的心态，不断追求新事物。4. 保持适当的休息：适当的休息可以让身体更加健康，提高工作效率。5. 保持积极的态度：积极的态度可以激发员工的创造力，提升工作的积极性。',
		},
		{
			ID: 5,
			Title: '挑选合适的礼物',
			Content: '请女客户吃饭，准备送一个小礼物，选什么礼物合适呢',
		},
		{
			ID: 6,
			Title: '解方程x²-y²=49',
			Content: '正整数x,y满足x^2-y^2=49，求x和y的值',
		},
		{
			ID: 7,
			Title: '计算球体体积',
			Content: '计算球体体积',
		},
		{
			ID: 8,
			Title: '爱护动物视频剧本',
			Content: '请担任编剧，我需要拍摄一个关于爱护动物的视频，请给我生成拍摄内容和脚本',
		},
		{
			ID: 9,
			Title: '诗意翻译：日月与爱',
			Content: '翻译为英文：浮世万千，吾爱有三，日、月、卿，日为朝，月为暮，卿为朝朝暮暮。',
		},
	],
	activeLabelName: 0,
	isShowExpand: false,
});
onMounted(() => {
	state.exampleContentList.forEach((item) => {
		item.BgColor = randomHexColor();
	});
});

const changeExample = (item) => {
	state.exampleIndex = item.ID;
};
//高级示例
const advanceExampleClick = () => {
	state.isShowAdvanceExample = true;
};
//切换到指令/提问
const handleTabClick = (item) => {
	state.activeName = item.ID;
};
//标签点击事件
const handleLabelClick = (item) => {
	state.activeLabelName = item.ID;
};
//展开收起
const handleExpandClick = (type) => {
	if (type == 1) {
		state.isShowExpand = true;
	} else {
		state.isShowExpand = false;
	}
};
//随机生成颜色
const randomHexColor = () => {
	return `#${Math.floor(Math.random() * 16777215)
		.toString(16)
		.padEnd(6, '0')}`;
};
</script>
<style scoped lang="scss">
.pc-prompts {
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	margin-top: 40px;
	width: 760px;
	padding: 0;
	font-size: 14px;
	.title {
		color: #999;
		line-height: 14px;
		.split {
			height: 12px;
			width: 2px;
			background-color: #ccc;
			margin: 0 10px;
		}
		span {
			color: rgb(32, 33, 35);
			font-size: 14px;
		}
		.changeBatch {
			color: #999;
			font-size: 12px;
			transition: color 0.2s ease-in-out;
		}
		.change {
			color: #999;
			transition: color 0.2s ease-in-out;
		}
	}
	.main {
		width: calc(100% + 16px);
		display: flex;
		flex-wrap: wrap;
		margin: 4px -8px 0;
		&_item {
			box-sizing: border-box;
			width: calc(50% - 16px);
			margin: 8px;
			padding: 12px;
			border: 1px solid #d9dbde;
			border-radius: 5px;
			background-color: transparent;
			-webkit-transition: border-color 0.2s, background-color 0.2s;
			-o-transition: border-color 0.2s, background-color 0.2s;
			transition: border-color 0.2s, background-color 0.2s;

			.left {
				width: 50px;
				height: 50px;
				border-radius: 5px;
			}
			.color0 {
				background: linear-gradient(180deg, #f63c8b, #fd216c);
			}
			.color1 {
				background: linear-gradient(180deg, #0ebfe1, #0ab2d3);
			}
			.color2 {
				background: linear-gradient(180deg, #9647fe, #7b5be8);
			}
			.color3 {
				background: linear-gradient(180deg, #fb894c, #ff7958);
			}
			.right {
				flex: 1;
				min-width: 0;
				margin-left: 12px;
				h4 {
					color: #202123;
					font-size: 13px;
					font-weight: 500;
					height: 16px;
					transition: background-color 0.2s;
				}
				p {
					font-size: 12px;
					margin-top: 6px;
					height: 34px;
					line-height: 17px;
					color: #8d8e99;
					overflow: hidden;
					-o-text-overflow: ellipsis;
					text-overflow: ellipsis;
					-webkit-line-clamp: 2;
					-webkit-box-orient: vertical;
				}
			}
		}
		&_item_active {
			border: 1px solid #007aff;
			background-color: #ebeef3;
			.right {
				h4 {
					color: #007aff;
				}
			}
		}
	}
}
.tabbar-item {
	width: 108px;
	height: 30px;
	font-size: 13px;
	font-weight: 400;
	line-height: 30px;
	text-align: center;
	cursor: pointer;
	// position: absolute;
	-o-transition: color 0.2s;
	transition: color 0.2s;
	&:nth-child(3) {
		top: 0;
		left: 0;
	}
}
.tabbar-item-active {
	color: #fff;
}
.set-tabbar-active {
	left: 95px;
	color: #fff;
	background-color: #000;
}
.set-input {
	:deep(.el-input__wrapper) {
		border: none;
		outline: none;
		-webkit-box-flex: 1;
		-ms-flex: 1;
		flex: 1;
		min-width: 0;
		height: 100%;
		-webkit-box-sizing: border-box;
		box-sizing: border-box;
		padding: 5px 12px;
		line-height: 20px;
		border-radius: 15px;
		color: #555;
		font-size: 13px;
		background-color: transparent;
		box-shadow: unset;
	}
}
.set-expand-active {
	max-height: 180px;
}
.set-label-active {
	border-color: #1c86ff;
	background-color: #ccdcfb;
	color: #1c86ff;
}
</style>
